// Steve Quinn 31/12/16
//
// Copyright 2016 Steve Quinn
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//
// Compiled using Arduino 1.6.9, Tested with ATTiny85 
//
// Uses the following libraries;
// ATTiny Core By Spence Konde : https://github.com/SpenceKonde/ATTinyCore/blob/master/README.md
// TinyWireS By Eero af Heurlin : https://github.com/rambo/TinyWire/tree/master/TinyWireS
//
// ATtiny85 acts as a slave I2C device (address 0x08). When sent a single hex control byte 0 ... 255 this is forwarded to PWM1 
// on the device. 
//
// ATMEL ATTINY85 / ARDUINO Pin connections
//
//                           +-\/-+
//            N/C (nRESET)  1|    |8   VCC (2.7-5.5V)
//            N/C    (D 3)  2|    |7   PI2C SCL
//            N/C    (D 4)  3|    |6   (D 1) PWM1 O/P
//                     GND  4|    |5   I2C SDA
//                           +----+
//
// Note : 1. When using the Arduino Uno R3 to debug, the output led should be connected to the PWM pin 9.
//        2. If this is the only device on your I2C bus, don't forget to add 10K pull up resistors to SDA and SCL lines
//           See : http://www.instructables.com/id/Arduino-I2C-LCD-Driver-Library-and-PackMan/ : I2C_LCD_With_Arduino.pdf




#include "TinyWireS.h"                  // wrapper class for I2C slave routines

#define I2C_SLAVE_ADDR  0x08            // i2c slave address 
#define PWM1               1            // ATtiny Pin 6
#define PWM_OFF         0x00            // Const to turn PWM ouput off

void setup(){
  pinMode(PWM1,OUTPUT);                 // Led output pin
  analogWrite(PWM1, PWM_OFF);           // ensure output is low
  TinyWireS.begin(I2C_SLAVE_ADDR);      // init I2C Slave mode
}


void loop(){
  byte byteRcvd = 0;
  if (TinyWireS.available()){           // got I2C input!
    byteRcvd = TinyWireS.receive();     // get the byte from master
    analogWrite(PWM1, byteRcvd);
  }
}



